about summary refs log tree commit diff
path: root/pkgs/test
diff options
context:
space:
mode:
authorDennis Gosnell <cdep.illabout@gmail.com>2023-05-30 09:06:42 +0900
committerDennis Gosnell <cdep.illabout@gmail.com>2023-05-30 09:06:42 +0900
commitdd9e4575ec2eb18e0cb005f36d52a8d5edea84df (patch)
tree79720e036d10a50704a93aadd82fcda0a2155ed8 /pkgs/test
parent6ddd5973f4c219331c5f94a7852716b947ae35f7 (diff)
downloadnixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.tar
nixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.tar.gz
nixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.tar.bz2
nixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.tar.lz
nixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.tar.xz
nixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.tar.zst
nixlib-dd9e4575ec2eb18e0cb005f36d52a8d5edea84df.zip
tests.haskell.incremental: change package used from turtle to temporary
With a recent hackage update, turtle stopped compiling on ghc94.  This
commit changes the tests.haskell.incremental test to use the temporary
package instead of turtle.
Diffstat (limited to 'pkgs/test')
-rw-r--r--pkgs/test/haskell/incremental/default.nix18
1 files changed, 9 insertions, 9 deletions
diff --git a/pkgs/test/haskell/incremental/default.nix b/pkgs/test/haskell/incremental/default.nix
index b94a85277db3..4509939ba4f4 100644
--- a/pkgs/test/haskell/incremental/default.nix
+++ b/pkgs/test/haskell/incremental/default.nix
@@ -9,26 +9,26 @@ let
   inherit (haskell.lib.compose) overrideCabal;
 
   # Incremental builds work with GHC >=9.4.
-  turtle = haskell.packages.ghc944.turtle;
+  temporary = haskell.packages.ghc944.temporary;
 
   # This will do a full build of `turtle`, while writing the intermediate build products
   # (compiled modules, etc.) to the `intermediates` output.
-  turtle-full-build-with-incremental-output = overrideCabal (drv: {
+  temporary-full-build-with-incremental-output = overrideCabal (drv: {
     doInstallIntermediates = true;
     enableSeparateIntermediatesOutput = true;
-  }) turtle;
+  }) temporary;
 
   # This will do an incremental build of `turtle` by copying the previously
   # compiled modules and intermediate build products into the source tree
   # before running the build.
   #
   # GHC will then naturally pick up and reuse these products, making this build
   # complete much more quickly than the previous one.
-  turtle-incremental-build = overrideCabal (drv: {
-    previousIntermediates = turtle-full-build-with-incremental-output.intermediates;
-  }) turtle;
+  temporary-incremental-build = overrideCabal (drv: {
+    previousIntermediates = temporary-full-build-with-incremental-output.intermediates;
+  }) temporary;
 in
-  turtle-incremental-build.overrideAttrs (old: {
+  temporary-incremental-build.overrideAttrs (old: {
     meta = {
       maintainers = lib.teams.mercury.members;
     };
@@ -9,26 +9,26 @@ let
 
-  # This will do a full build of `turtle`, while writing the intermediate build products
+  # This will do a full build of `temporary`, while writing the intermediate build products
   # (compiled modules, etc.) to the `intermediates` output.
@@ -9,26 +9,26 @@ let
 
-  # This will do an incremental build of `turtle` by copying the previously
+  # This will do an incremental build of `temporary` by copying the previously
   # compiled modules and intermediate build products into the source tree
   # before running the build.